## mmCIF Utility Classes

### Introduction

This module contains a collection of utility classes used by the Protein Data Bank
to manage structure and chemical reference definition mmCIF data objects.

### Installation

Download the library source software from the project repository:

```bash

git clone  https://github.com/rcsb/py-mmcif_utils.git

```

Optionally, run test suite (Python versions 2.7 or 3.7) using:

```bash
python setup.py test
```

Installation is via the program [pip](https://pypi.python.org/pypi/pip).

```bash
pip install -e .
```

